/*
 *  HID driver for N-Trig touchscreens
 *
 *  Copyright (c) 2009-2010 Rafi Rubin
 *  Copyright (c) 2009-2010 Stephane Chatty
 *
 */

/*
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <usb.h>



static struct usb_device **
device_init ()
{
  struct usb_bus *usb_bus;
  struct usb_device *dev;

  /* calloc to pre-zero */
  struct usb_device ** out = (struct usb_device **)calloc(8,
		  sizeof(struct usb_device *));
  int count = 0;

  usb_init ();
  usb_find_busses ();
  usb_find_devices ();

  for (usb_bus = usb_busses ; usb_bus ; usb_bus = usb_bus->next)
  {
	  //printf("bus %u\n",usb_bus->location);
	  for (dev = usb_bus->devices ; dev ; dev = dev->next)
		  if (dev->descriptor.idVendor == 0x1b96 && dev->descriptor.idProduct == 0x1)
			  out[count++] = dev;
  }
  return out;
}

#define BUFSIZE 1024

int main (int argc, char ** argv)
{
  struct usb_device *usb_dev;
  struct usb_device ** devs;
  struct usb_dev_handle *usb_handle;
  int retval = 1;

  unsigned char * buf;

 // int bytes=0;
//  int value = 0x402;
  int d;


  buf = (unsigned char *)malloc(BUFSIZE);
  buf[0] = 0;

  devs = device_init ();
  for(d=0; devs[d] != 0 && d<8 ; d++)
  {
	  usb_dev = devs[d];
	  if (!usb_dev) {
	    fprintf (stderr, "device not found\n");
	    return 0;
	  }

	  usb_handle = usb_open (usb_dev);
	  if (!usb_handle) {
	    fprintf (stderr, "could not open device\n");
	    return 0;
	  }

	  retval = usb_claim_interface (usb_handle,0);
	  retval = usb_claim_interface (usb_handle,1);
	  retval = usb_claim_interface (usb_handle,2);
	  retval = usb_control_msg (usb_handle, 0xa1, 0x01, 0x030c, 1, (char *)buf,8, 1000);
	  printf ("firmware version: %02x%02x%02x%02x %02x%02x%02x%02x\n"
			  ,buf[0],buf[1],buf[2],buf[3],buf[4],buf[5],buf[6],buf[7]);
	  retval = usb_control_msg (usb_handle, 0xa1, 0x01, 0x030d, 1, (char *)buf,8, 1000);
	  printf ("mode: %02x%02x%02x%02x\n"
			  ,buf[0],buf[1],buf[2],buf[3]);

	  retval = usb_release_interface (usb_handle,0);
	  retval = usb_release_interface (usb_handle,1);
	  retval = usb_release_interface (usb_handle,2);

	  usb_close (usb_handle);
  }

  free(buf);

  return 0;
}
